import logging
import requests

from retry.api import retry_call


class LoggedRequest(object):

    @staticmethod
    def get(url, params=None, **kwargs):
        logger = logging.getLogger(__name__)

        try:
            response = retry_call(
                LoggedRequest.__get,
                fargs=(url,  params),
                fkwargs=kwargs,
                tries=4,
                delay=1,
                backoff=3,
                logger=logger
            )

        except Exception as e:
            logger.debug('API request failed\n\turl: %s\n\tparams: %s\n\tkwargs: %s.', url, params, kwargs)
            logger.exception(e)
            raise e

        return response

    @staticmethod
    def __get(url, params=None, **kwargs):
        response = requests.get(url, params, timeout=5, **kwargs)
        response.raise_for_status()
        return response






# class _VirtualLcd(object):
#     LCD_LINE_1 = 0
#     LCD_LINE_2 = 1
#
#     def lcd_init(self, *args):
#         pass


# noinspection PyClassHasNoInit
class VirtualLcd(object):
    # LCD = _VirtualLcd()
    LCD_LINE_1 = 0
    LCD_LINE_2 = 1

    def lcd_init(self, *args):
        pass




import logging
from PackageInfo import PackageInfo
from ClientOptionParser import ClientOption


class ContextFilter(logging.Filter):
    def __init__(self, opts):
        self.__device_id = opts.get(ClientOption.DEVICE_ID)
        self.__app_id = PackageInfo.pip_package_name
        self.__version = PackageInfo.version or '0.0.0'
        self.__user_info = None

    def update_user_context(self, user_info):
        self.__user_info = user_info

    def filter(self, record):
        record.app_id = self.__app_id
        record.device_id = self.__device_id
        record.version = self.__version

        if self.__user_info:
            record.user_id = self.__user_info.get('user_id')
            record.user_name = self.__user_info.get('user_name')
            record.badge_code = self.__user_info.get('badge_code')
            record.device_name = self.__user_info.get('device_name')
        else:
            record.user_id = \
                record.user_name = \
                record.badge_id = \
                record.badge_code = \
                record.device_name = ''

        return True
